# mmpxrt

This is a raytracing code for design and analysis of x-ray spectrometers. Useful tool for experienced physicist.
For more info about distribution, installation, usage of this package, please see 
https://gitlab.hzdr.de/smid55/mmpxrt

The packaging was done by using this manual: https://packaging.python.org/tutorials/packaging-projects/
